@@ -44,6 +44,7 @@ class PersistentVolumeClaim(NamespacedResource):
         teardown=True,
         yaml_file=None,
         delete_timeout=TIMEOUT_4MINUTES,
+        pvlabel=None,
         **kwargs,
     ):
         super().__init__(
@@ -60,35 +61,37 @@ class PersistentVolumeClaim(NamespacedResource):
         self.size = size
         self.hostpath_node = hostpath_node
         self.storage_class = storage_class
+        self.pvlabel = pvlabel
 
     def to_dict(self):
-        res = super().to_dict()
-        if self.yaml_file:
-            return res
-
-        res.update(
-            {
-                "spec": {
-                    "volumeMode": self.volume_mode,
-                    "accessModes": [self.accessmodes],
-                    "resources": {"requests": {"storage": self.size}},
+        super().to_dict()
+        if not self.yaml_file:
+            self.res.update(
+                {
+                    "spec": {
+                        "volumeMode": self.volume_mode,
+                        "accessModes": [self.accessmodes],
+                        "resources": {"requests": {"storage": self.size}},
+                    }
                 }
-            }
-        )
-        """
-        Hostpath-provisioner is "node aware", when using it,
-        a node attribute on the claim must be introduced as follows.
-        annotations:
-          kubevirt.io/provisionOnNode: <specified_node_name>
-        """
-        if self.hostpath_node:
-            res["metadata"]["annotations"] = {
-                "kubevirt.io/provisionOnNode": self.hostpath_node
-            }
-        if self.storage_class:
-            res["spec"]["storageClassName"] = self.storage_class
+            )
+            """
+            Hostpath-provisioner is "node aware", when using it,
+            a node attribute on the claim must be introduced as follows.
+            annotations:
+              kubevirt.io/provisionOnNode: <specified_node_name>
+            """
+            if self.hostpath_node:
+                self.res["metadata"]["annotations"] = {
+                    "kubevirt.io/provisionOnNode": self.hostpath_node
+                }
+            if self.storage_class:
+                self.res["spec"]["storageClassName"] = self.storage_class
 
-        return res
+            if self.pvlabel:
+                self.res["spec"]["selector"] = {
+                    "matchLabels": {"pvLabel": self.pvlabel}
+                }
 
     def bound(self):
         """
