@@ -2,4 +2,4 @@ from ocp_resources.resource import Resource
 
 
 class VirtualMachineClusterInstancetype(Resource):
-    api_group = Resource.ApiGroup.INSTANCE_TYPE_KUBEVIRT_IO
+    api_group = Resource.ApiGroup.INSTANCETYPE_KUBEVIRT_IO
